package com.ruoyi.frequency.orderchangerecord.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.frequency.orderchangerecord.entity.OrderChangeRecord;

import java.util.List;

/**
 * 订单改价记录Mapper接口
 * 
 * @author zj
 * @date 2023-10-13
 */
public interface OrderChangeRecordMapper  extends BaseMapper<OrderChangeRecord>
{
    /**
     * 查询订单改价记录
     * 
     * @param id 订单改价记录主键
     * @return 订单改价记录
     */
    public OrderChangeRecord selectOrderChangeRecordById(Long id);

    /**
     * 查询订单改价记录列表
     * 
     * @param orderChangeRecord 订单改价记录
     * @return 订单改价记录集合
     */
    public List<OrderChangeRecord> selectOrderChangeRecordList(OrderChangeRecord orderChangeRecord);

    /**
     * 新增订单改价记录
     * 
     * @param orderChangeRecord 订单改价记录
     * @return 结果
     */
    public int insertOrderChangeRecord(OrderChangeRecord orderChangeRecord);

    /**
     * 修改订单改价记录
     * 
     * @param orderChangeRecord 订单改价记录
     * @return 结果
     */
    public int updateOrderChangeRecord(OrderChangeRecord orderChangeRecord);

    /**
     * 删除订单改价记录
     * 
     * @param id 订单改价记录主键
     * @return 结果
     */
    public int deleteOrderChangeRecordById(Long id);

    /**
     * 批量删除订单改价记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderChangeRecordByIds(Long[] ids);
}
